@@ -50,8 +50,49 @@ def pareto_graph(variable, salida='tabla'):
     else:
         return (pareto)
 
+def fis_bs_pareto_graph(variable, salida='tabla'):
+    #Ordenar en descendente y pasar a dataframe
+    pareto = variable.sort_values(ascending=False).to_frame()
+    #Cambiar el nombre a la variable
+    pareto.columns = ['Valor']
+    #Crear la posición
+    pareto['Posicion'] = np.arange(start=1, stop=len(pareto) + 1)
+    pareto['Posicion_Porc'] = pareto.Posicion.transform(
+        lambda x: x / pareto.shape[0] * 100)
+    #Crear el acumulado
+    pareto['Acum'] = pareto['Valor'].cumsum()
+    max_pareto_acum = max(pareto.Acum)
+    pareto['Acum_Porc'] = pareto.Acum.transform(
+        lambda x: x / max_pareto_acum * 100)
+    #Simplificar
+    pareto = pareto[['Posicion_Porc', 'Acum_Porc']]
 
-def clean_df_columns(df):
+    value = 80
+    idx = (pareto["Acum_Porc"] - value).abs().idxmin()
+    idx2 = pareto["Acum_Porc"].idxmin()
+    nearest = pareto["Posicion_Porc"].loc[idx]
+    ini = pareto["Posicion_Porc"].loc[idx2]
+
+    #Devolver la salida
+    if salida == 'grafico':
+        f, ax = plt.subplots(figsize=(10, 5))
+        ax.plot(pareto.Posicion_Porc, pareto.Acum_Porc)
+        ax.plot(pareto.Posicion_Porc, pareto.Posicion_Porc)
+        ax.tick_params(axis='x', labelsize=12, labelrotation=90)
+        ax.set_xticks(pareto.Posicion_Porc, pareto.index, rotation='vertical')
+        ax.axvline(nearest, color='green', alpha=0.3)
+        ax.text(nearest + 2, 0, "%.1f %%" % (nearest))
+        ax.axhline(80, color='green', alpha=0.3, linestyle='dotted')
+        ax.set_title("Pareto graph for '%s' by '%s'" %
+                     (variable.name, variable.index.name))
+        ax.fill_between([ini, nearest, nearest, ini], [0, 0, 100, 100],
+                        alpha=0.3,
+                        color='green')
+        return (ax)
+    else:
+        return (pareto)
+
+def fis_tool_clean_df_columns(df):
     for col in df.columns:
         new_col = col.lower()
         new_col = new_col.replace(" ", "_")
@@ -295,3 +336,36 @@ def fis_bs_lollipop(df,valor1,valor2,figsize=(12,4),dpi=100,linewidth=5,size=10,
     plt.ylabel("")
     plt.yticks([])                                    
     return f, ax
+
+def fis_bs_mekko(ynp_values,xnp_values,x_labels,figsize=(12,5),color1='light blue',color2='grey',xticks_size=14,legend1='val1',legend2='val2',title_size=20,legend_size=20,label_y="",label_x=""):
+    # calculate x coordinates based on the width of the previous bars
+    # same as: [0, width[0], width[0] + width[1], width[0] + width[1] + width[2]]
+    width = [i/sum(x) for i in x]
+    fig, ax = plt.subplots(figsize=figsize)
+    mpl.rcParams['axes.titley'] = 1.25
+    adjusted_x, temp = [0], 0
+    for i in width[:-1]:
+        temp += i
+        adjusted_x.append(temp)
+    # Marimekko chart
+    plt.bar(adjusted_x, y, width=width, align='edge', edgecolor='black',color=color1)
+    plt.bar(adjusted_x, np.ones(len(y))-y, bottom=y, width=width, align='edge', edgecolor='black',color=color2)
+    # x and y ticks (%)
+    ax.set_yticks([0, 0.25, 0.5, 0.75, 1])
+    ax.set_yticklabels(['0%', '25%', '50%', '75%', '100%'])
+    ax.set_xticks([0, 0.25, 0.5, 0.75, 1])
+    ax.set_xticklabels(['0%', '25%', '50%', '75%', '100%'])
+    plt.ylim(0,1)
+    plt.xlim(0,1)
+    # twin y-axis to draw x-ticks at the top
+    axy = ax.twiny()
+    axy.set_xticks([(width[i]/2)+ v for i, v in enumerate(adjusted_x)])
+    axy.set_xticklabels(x_label, fontsize=xticks_size)
+    ax.set_ylabel(label_y)
+    ax.set_xlabel(labex_x)
+    plt.title(title,
+              loc='left', fontsize=title_size)
+    ax.legend([legend1,legend2], 
+               ncol=2, loc='upper left', fontsize=legend_size,
+                   frameon=False, bbox_to_anchor=(0,1.25))
+    return f, ax
